@@ -1,4 +1,6 @@
-from stapy.common.log import custom_logger
+import logging
+
+from stapy.common.log import create_logger
 from stapy.common.config import config
 from stapy.cli.parser import Parser
 
@@ -9,15 +11,15 @@ def main():
 
     parser = Parser()
 
-    logger = custom_logger("root", parser.get_log_level())
+    create_logger(parser.get_log_level())
 
-    logger.info("starting application")
+    logging.info("starting application")
 
     parser.parse_args()
 
     config.save()
 
-    logger.info("ending application")
+    logging.info("ending application")
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
